==> mrpt_0.9.6.orig.tar.gz: mrpt-0.9.6/libs/base/src/utils/mrpt_font_9x15.h <==
/* +---------------------------------------------------------------------------+
   |          The Mobile Robot Programming Toolkit (MRPT) C++ library          |
   |                                                                           |
   |                       http://www.mrpt.org/                                |
   |                                                                           |
   |   Copyright (C) 2005-2012  University of Malaga                           |
   |                                                                           |
   |    This software was written by the Machine Perception and Intelligent    |
   |      Robotics Lab, University of Malaga (Spain).                          |
   |    Contact: Jose-Luis Blanco  <jlblanco@ctima.uma.es>                     |
   |                                                                           |
   |  This file is part of the MRPT project.                                   |
   |                                                                           |
   |     MRPT is free software: you can redistribute it and/or modify          |
   |     it under the terms of the GNU General Public License as published by  |
   |     the Free Software Foundation, either version 3 of the License, or     |
   |     (at your option) any later version.                                   |
   |                                                                           |
   |   MRPT is distributed in the hope that it will be useful,                 |
   |     but WITHOUT ANY WARRANTY; without even the implied warranty of        |
   |     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         |
   |     GNU General Public License for more details.                          |
   |                                                                           |
   |     You should have received a copy of the GNU General Public License     |
   |     along with MRPT.  If not, see <http://www.gnu.org/licenses/>.         |
   |                                                                           |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_9x15 [] = {
31,139,8,0,0,0,0,0,4,3,237,154,191,139,93,199,
21,199,55,151,37,40,198,36,139,8,65,132,197,92,150,45,
182,220,34,133,139,69,92,30,91,8,87,198,164,116,33,132,
203,16,132,73,17,130,88,46,15,37,17,198,133,16,4,146,
34,65,44,73,227,202,164,72,17,182,48,91,184,8,198,127,
128,43,147,58,133,113,45,148,124,62,218,57,206,241,188,185,
251,222,85,4,105,222,23,62,123,102,206,156,51,103,126,220,
251,246,105,237,239,237,236,236,252,0,212,191,175,204,139,159,
127,227,231,8,29,44,39,218,95,224,223,106,123,2,219,19,
216,158,192,246,4,182,39,176,61,129,255,255,9,236,177,132,
41,98,117,49,30,253,108,239,208,9,178,127,211,246,33,129,
114,86,108,221,158,154,199,53,61,128,39,112,19,126,8,111,
194,219,240,24,244,59,110,92,173,135,56,222,42,88,207,24,
113,31,127,46,44,176,45,189,142,211,122,129,253,15,225,29,
56,40,214,126,75,81,167,181,166,86,124,248,122,26,145,123,
131,118,139,24,55,54,203,216,60,214,211,175,137,113,99,107,
57,230,89,254,20,60,95,173,125,253,155,42,230,215,62,135,
220,223,116,142,58,238,24,135,244,5,231,188,78,214,125,21,
138,186,173,185,70,156,67,161,199,186,38,241,92,119,11,29,
182,37,207,246,20,150,19,56,102,76,75,214,184,5,190,3,
62,151,81,55,219,169,253,251,142,68,205,129,118,15,121,205,
174,119,42,87,255,8,3,244,112,31,198,132,243,58,127,75,
3,206,187,240,54,220,1,247,183,0,231,28,18,52,87,100,
76,87,248,21,246,55,48,38,174,171,251,75,226,118,161,206,
55,39,152,90,115,222,239,64,124,95,136,115,246,158,91,239,
16,238,23,119,231,30,173,161,173,239,59,124,12,173,40,223,
145,249,151,112,1,99,97,192,158,192,58,29,19,32,89,45,
95,30,143,118,43,46,124,61,65,178,7,161,129,70,15,250,
242,243,111,91,95,15,3,108,34,207,61,148,219,225,203,118,
151,78,93,99,192,215,67,94,11,221,21,229,115,30,25,29,
160,7,243,68,133,189,234,253,247,103,206,253,26,247,7,240,
15,248,43,116,5,99,90,114,206,35,240,25,88,38,220,107,
238,211,93,209,109,60,11,48,78,155,251,217,199,208,138,98,
205,29,35,45,204,159,90,115,93,199,216,204,130,190,49,45,
61,199,217,37,140,203,125,219,198,180,180,73,174,249,45,181,
246,251,79,2,151,137,169,253,230,24,219,174,163,246,217,111,
201,57,227,25,154,178,83,117,191,250,206,206,206,64,254,20,
11,198,78,160,37,215,227,248,1,248,123,225,251,240,90,105,
235,115,108,9,45,117,56,215,49,117,71,206,41,159,194,71,
133,39,88,137,49,109,75,49,238,103,186,239,144,57,231,112,
9,49,166,109,201,51,204,49,173,246,212,57,159,85,185,246,
187,6,184,86,116,93,221,216,131,49,61,124,2,89,173,186,
222,213,1,44,32,246,144,115,162,157,235,186,214,125,184,11,
35,68,158,49,45,121,119,83,207,98,246,183,114,99,238,235,
236,84,221,156,227,231,93,224,231,95,96,253,150,114,174,237,
120,166,194,250,172,57,95,75,145,235,184,117,98,143,245,231,
238,156,220,152,35,108,43,215,115,30,97,128,30,140,189,1,
187,208,21,140,169,229,247,20,227,54,193,216,90,206,109,13,
113,142,88,99,79,123,40,140,216,90,39,56,250,13,49,182,
150,117,142,224,20,150,245,224,43,234,231,191,59,59,101,236,
175,127,5,243,251,220,142,133,103,88,247,112,9,23,208,82,
135,51,136,239,162,230,4,126,142,233,95,39,235,154,19,115,
105,237,235,111,105,196,25,184,182,75,48,62,176,63,181,102,
134,190,81,212,53,207,231,176,43,76,213,189,207,248,163,130,
231,46,183,139,141,190,118,157,92,219,34,113,66,219,218,121,
61,121,13,177,46,109,235,156,151,248,165,165,91,201,185,79,
59,222,133,108,115,173,20,254,226,243,52,250,238,125,104,176,
192,23,156,208,14,117,52,130,37,237,123,240,99,248,110,177,
246,245,183,52,181,206,77,214,156,231,251,57,157,248,124,204,
118,170,110,206,157,123,206,57,215,243,180,70,205,212,57,231,
220,86,221,120,143,58,2,131,156,19,237,11,26,151,144,235,
218,215,63,38,104,174,232,125,60,254,237,230,33,236,86,208,
189,86,177,95,215,102,123,4,215,96,123,74,241,190,156,17,
16,237,176,143,240,249,188,173,211,130,128,22,238,119,157,92,
159,156,22,142,176,226,51,182,78,145,155,159,169,235,126,255,
230,249,162,102,212,210,186,6,253,235,180,32,160,230,30,190,
119,97,40,99,39,216,150,252,124,27,160,7,247,120,3,188,
103,253,181,190,196,145,223,181,158,190,159,35,98,59,143,125,
73,63,43,143,109,210,206,185,126,71,207,57,174,241,184,96,
59,143,25,91,203,231,215,59,241,76,182,218,158,192,246,4,
182,39,176,61,129,237,9,108,79,96,123,2,173,19,136,239,
19,49,22,253,150,141,152,150,237,113,250,189,235,29,184,9,
175,193,91,160,207,239,88,45,221,199,249,8,252,94,35,249,
223,145,175,211,255,0,126,1,83,90,50,240,0,226,251,171,
109,125,235,100,140,152,119,4,230,185,223,176,177,119,92,43,
138,177,108,13,202,253,104,215,201,126,119,60,4,207,35,218,
246,37,190,87,70,27,215,55,58,165,37,47,171,19,18,23,
240,7,248,11,252,186,88,251,250,29,159,146,247,224,125,238,
23,27,177,222,213,38,122,76,208,29,112,95,206,35,182,245,
57,182,169,206,8,28,18,155,230,69,220,131,104,172,177,238,
207,51,249,35,120,86,218,223,149,246,186,179,114,141,47,171,
99,18,61,19,177,61,71,123,4,7,207,83,91,159,210,55,
165,184,95,99,109,119,240,198,84,112,229,143,220,27,248,205,
247,110,245,173,83,79,128,241,230,253,175,90,50,65,205,167,
248,254,14,238,69,178,158,209,57,79,92,208,126,218,0,215,
90,29,19,33,175,82,206,231,251,225,231,65,104,151,134,127,
51,210,6,173,127,251,69,124,182,251,116,14,10,182,213,237,
43,179,209,207,250,125,125,76,150,207,168,107,116,108,74,245,
154,31,18,248,57,60,5,231,248,24,62,129,150,234,220,247,
8,250,19,140,112,23,246,224,43,104,169,126,38,159,16,244,
25,60,133,117,117,157,87,105,197,231,211,181,248,12,45,11,
15,176,89,142,199,243,175,255,77,56,133,136,247,221,139,182,
54,107,160,211,67,212,157,147,107,206,17,88,75,205,201,53,
254,67,120,223,6,154,155,107,205,151,173,27,181,180,177,254,
56,159,235,206,202,117,170,127,129,207,93,230,172,234,127,77,
191,37,239,206,90,221,4,142,25,115,12,135,112,11,118,33,
223,175,107,212,39,39,169,109,223,177,172,129,78,15,113,191,
115,114,235,251,157,147,75,201,23,247,115,106,3,205,201,117,
31,121,191,158,135,107,105,225,88,214,64,167,135,216,239,156,
220,122,191,115,114,41,249,173,253,206,205,53,255,54,44,192,
103,64,126,155,218,246,29,51,166,86,126,143,140,243,239,212,
126,111,125,82,56,199,94,130,99,89,173,115,54,166,197,38,
231,220,202,211,87,231,182,206,121,211,92,215,159,247,235,220,
115,114,125,30,227,153,156,155,107,237,144,53,157,199,207,143,
188,31,253,45,141,56,173,119,9,231,133,184,31,239,74,188,
55,99,58,8,213,119,228,252,83,152,155,53,208,233,33,222,
133,169,60,253,117,110,222,19,195,147,53,91,185,198,231,115,
158,83,119,32,183,135,122,205,249,172,29,11,104,174,168,195,
35,103,144,107,219,143,49,109,75,241,187,193,122,135,240,163,
98,99,63,218,159,64,173,248,188,234,203,128,231,57,22,158,
97,93,199,37,92,64,173,1,71,15,177,231,57,185,230,248,
12,186,46,53,39,215,248,223,195,123,54,208,220,92,107,190,
76,221,99,242,238,128,86,205,173,123,149,117,245,243,103,24,
223,163,199,224,60,55,75,223,223,209,235,100,188,247,226,179,
16,216,215,239,218,14,193,223,191,106,23,226,142,237,71,174,
241,207,33,242,245,215,26,112,244,176,7,106,78,174,57,245,
253,90,115,147,186,214,170,239,104,211,220,122,191,251,204,229,
90,106,90,251,237,75,156,231,165,230,228,154,227,255,67,124,
96,34,154,147,107,188,119,38,106,78,174,57,222,181,181,123,
112,95,113,86,217,234,111,41,255,78,106,253,183,227,152,163,
206,173,207,121,78,221,129,201,122,104,61,87,81,79,219,90,
243,117,207,213,186,92,166,220,232,119,112,171,174,185,167,5,
219,115,246,107,188,114,237,126,78,199,190,125,255,84,237,191,
242,174,254,28,113,89,247,188,224,231,71,252,14,214,223,65,
86,125,71,11,6,91,92,228,164,210,30,176,61,196,90,91,
121,250,90,185,230,228,119,127,78,46,169,223,122,23,230,228,
246,228,90,59,222,223,86,238,61,198,223,133,1,28,63,129,
172,142,78,80,191,15,126,207,209,23,227,218,144,239,161,168,
69,131,123,248,166,234,254,7,187,159,168,220,24,60,0,0,
};

==> mrpt_1.0.2.orig.tar.gz: mrpt-1.0.2/libs/base/src/utils/mrpt_font_9x15.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_9x15 [] = {
31,139,8,0,0,0,0,0,4,3,237,154,191,139,93,199,
21,199,55,151,37,40,198,36,139,8,65,132,197,92,150,45,
182,220,34,133,139,69,92,30,91,8,87,198,164,116,33,132,
203,16,132,73,17,130,88,46,15,37,17,198,133,16,4,146,
34,65,44,73,227,202,164,72,17,182,48,91,184,8,198,127,
128,43,147,58,133,113,45,148,124,62,218,57,206,241,188,185,
251,222,85,4,105,222,23,62,123,102,206,156,51,103,126,220,
251,246,105,237,239,237,236,236,252,0,212,191,175,204,139,159,
127,227,231,8,29,44,39,218,95,224,223,106,123,2,219,19,
216,158,192,246,4,182,39,176,61,129,255,255,9,236,177,132,
41,98,117,49,30,253,108,239,208,9,178,127,211,246,33,129,
114,86,108,221,158,154,199,53,61,128,39,112,19,126,8,111,
194,219,240,24,244,59,110,92,173,135,56,222,42,88,207,24,
113,31,127,46,44,176,45,189,142,211,122,129,253,15,225,29,
56,40,214,126,75,81,167,181,166,86,124,248,122,26,145,123,
131,118,139,24,55,54,203,216,60,214,211,175,137,113,99,107,
57,230,89,254,20,60,95,173,125,253,155,42,230,215,62,135,
220,223,116,142,58,238,24,135,244,5,231,188,78,214,125,21,
138,186,173,185,70,156,67,161,199,186,38,241,92,119,11,29,
182,37,207,246,20,150,19,56,102,76,75,214,184,5,190,3,
62,151,81,55,219,169,253,251,142,68,205,129,118,15,121,205,
174,119,42,87,255,8,3,244,112,31,198,132,243,58,127,75,
3,206,187,240,54,220,1,247,183,0,231,28,18,52,87,100,
76,87,248,21,246,55,48,38,174,171,251,75,226,118,161,206,
55,39,152,90,115,222,239,64,124,95,136,115,246,158,91,239,
16,238,23,119,231,30,173,161,173,239,59,124,12,173,40,223,
145,249,151,112,1,99,97,192,158,192,58,29,19,32,89,45,
95,30,143,118,43,46,124,61,65,178,7,161,129,70,15,250,
242,243,111,91,95,15,3,108,34,207,61,148,219,225,203,118,
151,78,93,99,192,215,67,94,11,221,21,229,115,30,25,29,
160,7,243,68,133,189,234,253,247,103,206,253,26,247,7,240,
15,248,43,116,5,99,90,114,206,35,240,25,88,38,220,107,
238,211,93,209,109,60,11,48,78,155,251,217,199,208,138,98,
205,29,35,45,204,159,90,115,93,199,216,204,130,190,49,45,
61,199,217,37,140,203,125,219,198,180,180,73,174,249,45,181,
246,251,79,2,151,137,169,253,230,24,219,174,163,246,217,111,
201,57,227,25,154,178,83,117,191,250,206,206,206,64,254,20,
11,198,78,160,37,215,227,248,1,248,123,225,251,240,90,105,
235,115,108,9,45,117,56,215,49,117,71,206,41,159,194,71,
133,39,88,137,49,109,75,49,238,103,186,239,144,57,231,112,
9,49,166,109,201,51,204,49,173,246,212,57,159,85,185,246,
187,6,184,86,116,93,221,216,131,49,61,124,2,89,173,186,
222,213,1,44,32,246,144,115,162,157,235,186,214,125,184,11,
35,68,158,49,45,121,119,83,207,98,246,183,114,99,238,235,
236,84,221,156,227,231,93,224,231,95,96,253,150,114,174,237,
120,166,194,250,172,57,95,75,145,235,184,117,98,143,245,231,
238,156,220,152,35,108,43,215,115,30,97,128,30,140,189,1,
187,208,21,140,169,229,247,20,227,54,193,216,90,206,109,13,
113,142,88,99,79,123,40,140,216,90,39,56,250,13,49,182,
150,117,142,224,20,150,245,224,43,234,231,191,59,59,101,236,
175,127,5,243,251,220,142,133,103,88,247,112,9,23,208,82,
135,51,136,239,162,230,4,126,142,233,95,39,235,154,19,115,
105,237,235,111,105,196,25,184,182,75,48,62,176,63,181,102,
134,190,81,212,53,207,231,176,43,76,213,189,207,248,163,130,
231,46,183,139,141,190,118,157,92,219,34,113,66,219,218,121,
61,121,13,177,46,109,235,156,151,248,165,165,91,201,185,79,
59,222,133,108,115,173,20,254,226,243,52,250,238,125,104,176,
192,23,156,208,14,117,52,130,37,237,123,240,99,248,110,177,
246,245,183,52,181,206,77,214,156,231,251,57,157,248,124,204,
118,170,110,206,157,123,206,57,215,243,180,70,205,212,57,231,
220,86,221,120,143,58,2,131,156,19,237,11,26,151,144,235,
218,215,63,38,104,174,232,125,60,254,237,230,33,236,86,208,
189,86,177,95,215,102,123,4,215,96,123,74,241,190,156,17,
16,237,176,143,240,249,188,173,211,130,128,22,238,119,157,92,
159,156,22,142,176,226,51,182,78,145,155,159,169,235,126,255,
230,249,162,102,212,210,186,6,253,235,180,32,160,230,30,190,
119,97,40,99,39,216,150,252,124,27,160,7,247,120,3,188,
103,253,181,190,196,145,223,181,158,190,159,35,98,59,143,125,
73,63,43,143,109,210,206,185,126,71,207,57,174,241,184,96,
59,143,25,91,203,231,215,59,241,76,182,218,158,192,246,4,
182,39,176,61,129,237,9,108,79,96,123,2,173,19,136,239,
19,49,22,253,150,141,152,150,237,113,250,189,235,29,184,9,
175,193,91,160,207,239,88,45,221,199,249,8,252,94,35,249,
223,145,175,211,255,0,126,1,83,90,50,240,0,226,251,171,
109,125,235,100,140,152,119,4,230,185,223,176,177,119,92,43,
138,177,108,13,202,253,104,215,201,126,119,60,4,207,35,218,
246,37,190,87,70,27,215,55,58,165,37,47,171,19,18,23,
240,7,248,11,252,186,88,251,250,29,159,146,247,224,125,238,
23,27,177,222,213,38,122,76,208,29,112,95,206,35,182,245,
57,182,169,206,8,28,18,155,230,69,220,131,104,172,177,238,
207,51,249,35,120,86,218,223,149,246,186,179,114,141,47,171,
99,18,61,19,177,61,71,123,4,7,207,83,91,159,210,55,
165,184,95,99,109,119,240,198,84,112,229,143,220,27,248,205,
247,110,245,173,83,79,128,241,230,253,175,90,50,65,205,167,
248,254,14,238,69,178,158,209,57,79,92,208,126,218,0,215,
90,29,19,33,175,82,206,231,251,225,231,65,104,151,134,127,
51,210,6,173,127,251,69,124,182,251,116,14,10,182,213,237,
43,179,209,207,250,125,125,76,150,207,168,107,116,108,74,245,
154,31,18,248,57,60,5,231,248,24,62,129,150,234,220,247,
8,250,19,140,112,23,246,224,43,104,169,126,38,159,16,244,
25,60,133,117,117,157,87,105,197,231,211,181,248,12,45,11,
15,176,89,142,199,243,175,255,77,56,133,136,247,221,139,182,
54,107,160,211,67,212,157,147,107,206,17,88,75,205,201,53,
254,67,120,223,6,154,155,107,205,151,173,27,181,180,177,254,
56,159,235,206,202,117,170,127,129,207,93,230,172,234,127,77,
191,37,239,206,90,221,4,142,25,115,12,135,112,11,118,33,
223,175,107,212,39,39,169,109,223,177,172,129,78,15,113,191,
115,114,235,251,157,147,75,201,23,247,115,106,3,205,201,117,
31,121,191,158,135,107,105,225,88,214,64,167,135,216,239,156,
220,122,191,115,114,41,249,173,253,206,205,53,255,54,44,192,
103,64,126,155,218,246,29,51,166,86,126,143,140,243,239,212,
126,111,125,82,56,199,94,130,99,89,173,115,54,166,197,38,
231,220,202,211,87,231,182,206,121,211,92,215,159,247,235,220,
115,114,125,30,227,153,156,155,107,237,144,53,157,199,207,143,
188,31,253,45,141,56,173,119,9,231,133,184,31,239,74,188,
55,99,58,8,213,119,228,252,83,152,155,53,208,233,33,222,
133,169,60,253,117,110,222,19,195,147,53,91,185,198,231,115,
158,83,119,32,183,135,122,205,249,172,29,11,104,174,168,195,
35,103,144,107,219,143,49,109,75,241,187,193,122,135,240,163,
98,99,63,218,159,64,173,248,188,234,203,128,231,57,22,158,
97,93,199,37,92,64,173,1,71,15,177,231,57,185,230,248,
12,186,46,53,39,215,248,223,195,123,54,208,220,92,107,190,
76,221,99,242,238,128,86,205,173,123,149,117,245,243,103,24,
223,163,199,224,60,55,75,223,223,209,235,100,188,247,226,179,
16,216,215,239,218,14,193,223,191,106,23,226,142,237,71,174,
241,207,33,242,245,215,26,112,244,176,7,106,78,174,57,245,
253,90,115,147,186,214,170,239,104,211,220,122,191,251,204,229,
90,106,90,251,237,75,156,231,165,230,228,154,227,255,67,124,
96,34,154,147,107,188,119,38,106,78,174,57,222,181,181,123,
112,95,113,86,217,234,111,41,255,78,106,253,183,227,152,163,
206,173,207,121,78,221,129,201,122,104,61,87,81,79,219,90,
243,117,207,213,186,92,166,220,232,119,112,171,174,185,167,5,
219,115,246,107,188,114,237,126,78,199,190,125,255,84,237,191,
242,174,254,28,113,89,247,188,224,231,71,252,14,214,223,65,
86,125,71,11,6,91,92,228,164,210,30,176,61,196,90,91,
121,250,90,185,230,228,119,127,78,46,169,223,122,23,230,228,
246,228,90,59,222,223,86,238,61,198,223,133,1,28,63,129,
172,142,78,80,191,15,126,207,209,23,227,218,144,239,161,168,
69,131,123,248,166,234,254,7,187,159,168,220,24,60,0,0,
};
